# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`fts`](#fts): This class installs the FTS3 server and configures it to run as a service.
It can also install the MySQL server and create the FTS3 database.
The class can be used to configure only the FTS3 server, only the MySQL server, or both.
* [`fts::client`](#fts--client): This class isntall the FTS client
* [`fts::database`](#fts--database): @summary: this class can create and configures the mysql fts database. Depending on the parameter choices,   it can create an mysql server, c
* [`fts::server`](#fts--server): This class defines the configuration for the FTS server.
It takes in parameters for configuring the server and sets up the
necessary resources.

## Classes

### <a name="fts"></a>`fts`

(optional) The number of threads to use for the FTS3 database.
defaults to 24.

#### Examples

##### 

```puppet
class { 'fts':
  fts_host           => 'fts3-server.example.org',
  db_host            => 'fts3-db.example.org',
  db_name            => 'fts',
  db_root_user       => 'root',
  db_root_password   => 'roottestpassword',
  fts_db_password    => 'ftstestpassword',
  fts_db_user        => 'fts3',
  fts_db_type        => 'mysql',
  fts_server_alias   => 'fts3-server',
  admin_list         => ['/DC=org/DC=terena/DC=tcs/C=IT/O=Istituto Nazionale di Fisica Nucleare/CN=Michele Delli Veneri delliven@infn.it'],
  fts_db_threads_num => 24,
  configure_db       => true,
  configure_fts      => true,
  configure_firewall => true,
  configure_selinux  => true,
  build_mysql_server => true,
  build_fts_tables   => true,
  grant_privileges   => true,
  configure_admins   => true,
  configure_lsc      => true,
  vo_list            => ['alice', 'atlas', 'cms', 'cygno', 'datacloud', 'dteam', 'escape', 'lhcb', 'ops', 'wlcg'],
}
```

#### Parameters

The following parameters are available in the `fts` class:

* [`fts_host`](#-fts--fts_host)
* [`db_host`](#-fts--db_host)
* [`db_name`](#-fts--db_name)
* [`db_root_user`](#-fts--db_root_user)
* [`db_root_password`](#-fts--db_root_password)
* [`fts_db_password`](#-fts--fts_db_password)
* [`fts_db_type`](#-fts--fts_db_type)
* [`fts_server_alias`](#-fts--fts_server_alias)
* [`admin_list`](#-fts--admin_list)
* [`fts_db_threads_num`](#-fts--fts_db_threads_num)
* [`configure_fts`](#-fts--configure_fts)
* [`configure_db`](#-fts--configure_db)
* [`configure_firewall`](#-fts--configure_firewall)
* [`configure_admins`](#-fts--configure_admins)
* [`configure_lsc`](#-fts--configure_lsc)
* [`configure_selinux`](#-fts--configure_selinux)
* [`build_mysql_server`](#-fts--build_mysql_server)
* [`vo_list`](#-fts--vo_list)
* [`build_fts_tables`](#-fts--build_fts_tables)
* [`grant_privileges`](#-fts--grant_privileges)
* [`fts_db_user`](#-fts--fts_db_user)

##### <a name="-fts--fts_host"></a>`fts_host`

Data type: `String`

(required) The hostname of the FTS3 server.
defaults to fts-server.infn.it
The value of this parameter is used to set the FTS3
server hostname in the MySQL database.

Default value: `'fts3-server.infn.it'`

##### <a name="-fts--db_host"></a>`db_host`

Data type: `String`

(required) The hostname of the FTS3 database.
Defaults to fts-db.infn.it
The value of this parameter is used to set the
FTS database hostname in the FTS configuration file.

Default value: `'fts3-db.infn.it'`

##### <a name="-fts--db_name"></a>`db_name`

Data type: `String`

(optional) the name of the fts database user.
defaults to fts3. The user will be created if it does not exist.

Default value: `'fts'`

##### <a name="-fts--db_root_user"></a>`db_root_user`

Data type: `String`

(optional) The username of the MySQL root user.
defaults to 'root'. If the mysql server is not built,
or grants to the root and fts users must not be given
becouse the database alredy exists, this parameter is ignored.

Default value: `'root'`

##### <a name="-fts--db_root_password"></a>`db_root_password`

Data type: `String`

(optional) the root password for the mysql server.
Defaults to roottestpassword. If the mysql server is not built,
or grants to the root and fts users must not be given
becouse the database alredy exists, this parameter is ignored.

Default value: `'dbrootpassword'`

##### <a name="-fts--fts_db_password"></a>`fts_db_password`

Data type: `String`

(optional) the password of the fts database user.
defaults to ftstestpassword. Please change this parameter to a secure password.

Default value: `'ftstestpassword'`

##### <a name="-fts--fts_db_type"></a>`fts_db_type`

Data type: `String`

(optional) The type of database backend to use.
defaults to mysql which is the only supported backend.

Default value: `'mysql'`

##### <a name="-fts--fts_server_alias"></a>`fts_server_alias`

Data type: `String`

(optional) The alias to use for the FTS server
defaults to fts3-server.

Default value: `'fts3-server'`

##### <a name="-fts--admin_list"></a>`admin_list`

Data type: `Array`

(required) the list of the admin users for the fts database.
defaults to ['/DC=org/DC=terena/DC=tcs/C=IT/O=Istituto Nazionale di Fisica Nucleare/CN=Michele Delli Veneri]
In order for the fts server to work, at least one admin user must be configured.
The admin user must be in the form of a DN.
Admins will be created if they do not exist only if the FTS database has been populated with tables
through the build_fts_tables parameter.

Default value: `['/DC=org/DC=terena/DC=tcs/C=IT/O=Istituto Nazionale di Fisica Nucleare/CN=Michele Delli Veneri delliven@infn.it']`

##### <a name="-fts--fts_db_threads_num"></a>`fts_db_threads_num`

Data type: `Integer`



Default value: `24`

##### <a name="-fts--configure_fts"></a>`configure_fts`

Data type: `Boolean`

(optional) Whether to configure the FTS3 server.
defaults to true. If this parameter is set to True, the FTS3 server will be configured, i.e. the
class fts::server will be included and used to install needed dependencies and configure the FTS3 service.
For further information about the parameters of the fts::server class, please refer to the documentation of the class.

Default value: `true`

##### <a name="-fts--configure_db"></a>`configure_db`

Data type: `Boolean`

(optional) Whether to configure the FTS3 MySQL database.
defaults to true. If this parameter is set to True, the FTS3 database will be configured, i.e. the
class fts::database will be included and used to install needed dependencies and configure the MySQL FTS3 database.
For further information about the parameters of the fts::database class, please refer to the documentation of the class.

Default value: `true`

##### <a name="-fts--configure_firewall"></a>`configure_firewall`

Data type: `Boolean`

(optional) Whether to configure the firewall.
defaults to true. If configure_fts is set to true,
the firewallthe firewall module opens the following ports:
8446 for the REST API, 8449 for the web monitoring.
If configure_db is set to true, the firewall module opens the following ports:
3306 for the MySQL server. All remaining ports are closed.

Default value: `true`

##### <a name="-fts--configure_admins"></a>`configure_admins`

Data type: `Boolean`

(required) Whether to configure the FTS3 administrators.
defaults to true. If set to true, the list of admins is taken from the admin_list parameter,
and the admins are created if they do not exist.

Default value: `true`

##### <a name="-fts--configure_lsc"></a>`configure_lsc`

Data type: `Boolean`

(optional) Whether to install and configure the servers as VOMS clients.
defaults to true. If set to false, VOMS must be already configured on the server. LSC setup for at least
one VO (and one admin for that VO) is required for the FTS3 server to work.

Default value: `true`

##### <a name="-fts--configure_selinux"></a>`configure_selinux`

Data type: `Boolean`

(optional) Whether to configure SELinux.
defaults to true. Selinux is set to enforcing on the FTS server, and to permissive on the MySQL server.

Default value: `true`

##### <a name="-fts--build_mysql_server"></a>`build_mysql_server`

Data type: `Boolean`

(optional) whether to build the mysql server or not.
defaults to true. if the mysql server is not built, the script assumes that
a mysql server is already running on the machine and that the root user and password are valid.

Default value: `true`

##### <a name="-fts--vo_list"></a>`vo_list`

Data type: `Array`

(optional) List of VOs to configure. Add the VOs to the list.
Possible values are 'alice', 'atlas', 'cms', 'cygno', 'datacloud', 'dteam',
'escape', 'lhcb', 'ops', 'wlcg'
defaults to [None].

Default value: `['cycgno', 'datacloud']`

##### <a name="-fts--build_fts_tables"></a>`build_fts_tables`

Data type: `Boolean`

(optional) Whether to build the FTS tables or not.
defaults to true. The script in either case will create and/or check the presente of the
fts database and the user. If the parameter is set to true, the fts database will be populated
with the tables needed for the fts server to work. If the parameter is set to false, the script will
only check the presence of the fts database and the user. The tables can be build both from the fts server through an
automatic SQL query on the MySQL database (in case the MySQL is CentOS 7),
or directly on the mySQL server by combining this flag with configure_db = true.

Default value: `true`

##### <a name="-fts--grant_privileges"></a>`grant_privileges`

Data type: `Boolean`

(optional) Whether to grant privileges to the FTS and root user on the database.
defaults to true. In order to grant privileges, the MySQL database, the FTS Tables,
and user must already exist and the MySQL root user and password must be provided.
Correct privileges to the fts database for, at least, the fts user are neeed for the fts server
to work. So, if the parameter is set to false, make sure to grant privilegs manually.

Default value: `true`

##### <a name="-fts--fts_db_user"></a>`fts_db_user`

Data type: `String`



Default value: `'fts3'`

### <a name="fts--client"></a>`fts::client`

A description of what this class does

#### Examples

##### 

```puppet
include fts::client
```

### <a name="fts--database"></a>`fts::database`

@summary: this class can create and configures the mysql fts database. Depending on the parameter choices,
  it can create an mysql server, create and configure the fts
  database and the user, populate it with tables, add admins,
  and configure the firewall and selinux.

#### Examples

##### Configure the fts database

```puppet
class { 'fts::database':
  db_root => 'root',
  db_root_password => 'ftstestpassword',
  db_name     => 'fts',
  fts_host    => 'fts-server.infn.it',
  fts_db_user => 'fts3',
  fts_db_password => 'ftstestpassword',
  admin_list  => ['/DC=org/DC=terena/DC=tcs/C=IT/O=Istituto Nazionale di Fisica Nucleare/CN=Michele Delli Veneri,
                    '/DC=org/DC=terena/DC=tcs/C=IT/O=Istituto Nazionale di Fisica Nucleare/CN=Massimo Sgaravatto sgaravat@infn.it'],
  configure_firewall => true,
  configure_selinux  => true,
  build_mysql_server => true,
  build_fts_tables   => true,
  grant_privileges   => true,
}
```

#### Parameters

The following parameters are available in the `fts::database` class:

* [`db_root_user`](#-fts--database--db_root_user)
* [`db_root_password`](#-fts--database--db_root_password)
* [`db_name`](#-fts--database--db_name)
* [`fts_host`](#-fts--database--fts_host)
* [`fts_db_user`](#-fts--database--fts_db_user)
* [`fts_db_password`](#-fts--database--fts_db_password)
* [`admin_list`](#-fts--database--admin_list)
* [`configure_firewall`](#-fts--database--configure_firewall)
* [`configure_selinux`](#-fts--database--configure_selinux)
* [`build_mysql_server`](#-fts--database--build_mysql_server)
* [`build_fts_tables`](#-fts--database--build_fts_tables)
* [`grant_privileges`](#-fts--database--grant_privileges)
* [`configure_admins`](#-fts--database--configure_admins)

##### <a name="-fts--database--db_root_user"></a>`db_root_user`

Data type: `String`

(optional) the root user for the mysql server,
defaults to root. If the mysql server is not built,
or grants to the root and fts users must not be given
becouse the database alredy exists, this parameter is ignored.

Default value: `'root'`

##### <a name="-fts--database--db_root_password"></a>`db_root_password`

Data type: `String`

(optional) the root password for the mysql server.
Defaults to roottestpassword. If the mysql server is not built,
or grants to the root and fts users must not be given
becouse the database alredy exists, this parameter is ignored.

Default value: `'roottestpassword'`

##### <a name="-fts--database--db_name"></a>`db_name`

Data type: `String`

(required) the name of the fts database.
defaults to fts. The database will be created if it does not exist.

Default value: `'fts'`

##### <a name="-fts--database--fts_host"></a>`fts_host`

Data type: `String`

(required) the hostname of the fts server. This can be the FQDN or
the IP address of the machine hosting the mysql db.

Default value: `'fts-server.infn.it'`

##### <a name="-fts--database--fts_db_user"></a>`fts_db_user`

Data type: `String`

(required) The user that will run the FTS server.
defaults to fts3.

Default value: `'fts3'`

##### <a name="-fts--database--fts_db_password"></a>`fts_db_password`

Data type: `String`

(optional) the password of the fts database user.
defaults to ftstestpassword. Please change this parameter to a secure password.

Default value: `'ftstestpassword'`

##### <a name="-fts--database--admin_list"></a>`admin_list`

Data type: `Array`

(required) the list of the admin users for the fts database. In order for the fts server to work,
at least one admin user must be configured. The admin user must be in the form of a DN.
Admins will be created if they do not exist only if the FTS database has been populated with tables
through the build_fts_tables parameter.

Default value: `['/DC=org/DC=terena/DC=tcs/C=IT/O=Istituto Nazionale di Fisica Nucleare/CN=Michele Delli Veneri delliven@infn.it']`

##### <a name="-fts--database--configure_firewall"></a>`configure_firewall`

Data type: `Boolean`

(optional) whether to configure the firewall or not.
defaults to true. The firewall will be configured to allow access only to the mysql server.

Default value: `true`

##### <a name="-fts--database--configure_selinux"></a>`configure_selinux`

Data type: `Boolean`

(optional) whether to configure selinux or not.
defaults to true. Selinux will be configured to permissive mode.

Default value: `true`

##### <a name="-fts--database--build_mysql_server"></a>`build_mysql_server`

Data type: `Boolean`

(optional) whether to build the mysql server or not.
defaults to true. if the mysql server is not built, the script assumes that
a mysql server is already running on the machine and that the root user and password are valid.

Default value: `true`

##### <a name="-fts--database--build_fts_tables"></a>`build_fts_tables`

Data type: `Boolean`

(optional) Whether to build the FTS tables or not. d
defaults to true. The script in either case will create and/or check the presente of the
fts database and the user. If the parameter is set to true, the fts database will be populated
with the tables needed for the fts server to work. If the parameter is set to false, the script will
only check the presence of the fts database and the user.

Default value: `true`

##### <a name="-fts--database--grant_privileges"></a>`grant_privileges`

Data type: `Boolean`

(optional) Whether to grant privileges to the FTS and root user on the database.
defaults to true. In order to grant privileges, the MySQL database, the FTS Tables,
and user must already exist and the MySQL root user and password must be provided.
Correct privileges to the fts database for, at least, the fts user are neeed for the fts server
to work. So, if the parameter is set to false, make sure to grant privilegs manually.

Default value: `true`

##### <a name="-fts--database--configure_admins"></a>`configure_admins`

Data type: `Boolean`

(optional) Whether to configure the FTS admins or not.
defaults to true. In order to configure the admins, the MySQL database,
the FTS Tables, and user must already exist.

Default value: `true`

### <a name="fts--server"></a>`fts::server`

}

o n a CentOS machine, otherwise building the tables must be done manually or by running
t he module on the database machine.

#### Examples

##### 

```puppet
class { 'fts::server':
  fts_user => 'fts3',
  fts_db_type => 'mysql',
  db_host => 'fts-db.infn.it',
  fts_db_name => 'fts',
  fts_db_password => 'ftstestpassword',
  fts_db_threads_num => 24,
  fts_server_alias => 'fts3-server',
  configure_firewall => true,
```

#### Parameters

The following parameters are available in the `fts::server` class:

* [`fts_user`](#-fts--server--fts_user)
* [`fts_db_type`](#-fts--server--fts_db_type)
* [`db_host`](#-fts--server--db_host)
* [`fts_db_name`](#-fts--server--fts_db_name)
* [`fts_db_password`](#-fts--server--fts_db_password)
* [`fts_db_threads_num`](#-fts--server--fts_db_threads_num)
* [`fts_server_alias`](#-fts--server--fts_server_alias)
* [`configure_firewall`](#-fts--server--configure_firewall)
* [`configure_selinux`](#-fts--server--configure_selinux)
* [`build_fts_tables`](#-fts--server--build_fts_tables)

##### <a name="-fts--server--fts_user"></a>`fts_user`

Data type: `String`

(required) The user that will run the FTS server.
defaults to fts3.

Default value: `'fts3'`

##### <a name="-fts--server--fts_db_type"></a>`fts_db_type`

Data type: `String`

(optional) The type of database backend to use.
defaults to mysql which is the only supported backend.

Default value: `'mysql'`

##### <a name="-fts--server--db_host"></a>`db_host`

Data type: `String`

(required) The hostname or IP of the machine hosting the mysql database..
defaults to fts-db.infn.it. This host must be accessible from the FTS server.

Default value: `'fts-db.infn.it'`

##### <a name="-fts--server--fts_db_name"></a>`fts_db_name`

Data type: `String`

(optional) The name of the mysql database hosted on the database server.
defaults to fts.

Default value: `'fts'`

##### <a name="-fts--server--fts_db_password"></a>`fts_db_password`

Data type: `String`

(optional) The password for the fts user to connect to the database.
defaults to ftstestpassword.

Default value: `'ftstestpassword'`

##### <a name="-fts--server--fts_db_threads_num"></a>`fts_db_threads_num`

Data type: `Integer`

(optional) The number of threads to use for the database backend.
defaults to 24.

Default value: `24`

##### <a name="-fts--server--fts_server_alias"></a>`fts_server_alias`

Data type: `String`

(optional) The alias to use for the FTS server
defaults to fts3-server.

Default value: `'fts3-server'`

##### <a name="-fts--server--configure_firewall"></a>`configure_firewall`

Data type: `Boolean`

(optional) Whether to configure the firewall or not.
defaults to true. If set to false, the firewall must be configured manually.
If set to true, the firewall module opens the following ports:
8446 for the REST API, 8449 for the web monitoring.

Default value: `true`

##### <a name="-fts--server--configure_selinux"></a>`configure_selinux`

Data type: `Boolean`

(optional) Whether to configure SELinux or not.
defaults to true. If set to true, it sets SELinux to enforcing mode.

Default value: `true`

##### <a name="-fts--server--build_fts_tables"></a>`build_fts_tables`

Data type: `Boolean`

(optional) Whether to build the FTS tables or not.
defaults to true.
In order to build the tables, the MySQL fts database,
and user must already exist. It can only be done if the mysql server is hosted

Default value: `true`

